Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CheckMetrics ¶
type CheckMetrics struct {
CheckError Meter
HandleError Meter
TriggersCheckTime Timer
TriggersToCheckCount Histogram
}
CheckMetrics is a collection of metrics for trigger checks
type CheckerMetrics ¶
type CheckerMetrics struct {
LocalMetrics *CheckMetrics
RemoteMetrics *CheckMetrics
MetricEventsChannelLen Histogram
UnusedTriggersCount Histogram
MetricEventsHandleTime Timer
}
CheckerMetrics is a collection of metrics used in checker
func (*CheckerMetrics) GetCheckMetrics ¶
func (metrics *CheckerMetrics) GetCheckMetrics(trigger *moira.Trigger) *CheckMetrics
GetCheckMetrics return check metrics dependent on given trigger type
type Config ¶
type Config struct {
Enabled bool
RuntimeStats bool
URI string
Prefix string
Interval time.Duration
}
Config for graphite connection settings
type FilterMetrics ¶
type FilterMetrics struct {
TotalMetricsReceived Counter
ValidMetricsReceived Counter
MatchingMetricsReceived Counter
MatchingTimer Timer
SavingTimer Timer
BuildTreeTimer Timer
MetricChannelLen Histogram
LineChannelLen Histogram
}
FilterMetrics is a collection of metrics used in filter
type Histogram ¶
type Histogram interface {
Clear()
Count() int64
Max() int64
Mean() float64
Min() int64
Percentile(float64) float64
Percentiles([]float64) []float64
StdDev() float64
Sum() int64
Update(int64)
Variance() float64
}
Histogram calculate distribution statistics from a series of int64 values.
type IndexMetrics ¶
IndexMetrics is a collection of metrics used in full-text search index
type Meter ¶
type Meter interface {
Count() int64
Mark(int64)
Rate1() float64
Rate5() float64
Rate15() float64
RateMean() float64
}
Meter count events to produce exponentially-weighted moving average rates at one-, five-, and fifteen-minutes and a mean rate.
type MetricsMap ¶
MetricsMap implements meter collection abstraction
type NotifierMetrics ¶
type NotifierMetrics struct {
SubsMalformed Meter
EventsReceived Meter
EventsMalformed Meter
EventsProcessingFailed Meter
SendingFailed Meter
SendersOkMetrics MetricsMap
SendersFailedMetrics MetricsMap
}
NotifierMetrics is a collection of metrics used in notifier
type Timer ¶
type Timer interface {
Count() int64
Max() int64
Mean() float64
Min() int64
Percentile(float64) float64
Percentiles([]float64) []float64
Rate1() float64
Rate5() float64
Rate15() float64
RateMean() float64
StdDev() float64
Sum() int64
Time(func())
Update(time.Duration)
UpdateSince(time.Time)
Variance() float64
}
Timer capture the duration and rate of events.
Directories
¶
| Path | Synopsis |
|---|---|
|
nolint nolint nolint nolint nolint nolint
|
nolint nolint nolint nolint nolint nolint |