Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Config ¶
type Config struct {
Enabled bool
RemoteTriggersEnabled bool
RedisDisconnectDelaySeconds int64
LastMetricReceivedDelaySeconds int64
LastCheckDelaySeconds int64
LastRemoteCheckDelaySeconds int64
NoticeIntervalSeconds int64
Contacts []map[string]string
}
Config is representation of self state worker settings like moira admins contacts and threshold values for checked services
type SelfCheckWorker ¶
type SelfCheckWorker struct {
Logger moira.Logger
DB moira.Database
Notifier notifier.Notifier
Config Config
// contains filtered or unexported fields
}
SelfCheckWorker checks what all notifier services works correctly and send message when moira don't work
func (*SelfCheckWorker) Start ¶
func (selfCheck *SelfCheckWorker) Start() error
Start self check worker
func (*SelfCheckWorker) Stop ¶
func (selfCheck *SelfCheckWorker) Stop() error
Stop self check worker and wait for finish
Click to show internal directories.
Click to hide internal directories.